CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
64 lines
2.0 KiB
Plaintext
64 lines
2.0 KiB
Plaintext
// RUN: %clang_cc1 %s -emit-llvm -o - -triple -amdgcn-amd-amdhsa \
|
|
// RUN: -target-cpu gfx906 -fcuda-is-device -x hip \
|
|
// RUN: | FileCheck --check-prefixes=COMMON,CRDIV %s
|
|
// RUN: %clang_cc1 %s -emit-llvm -o - -triple -amdgcn-amd-amdhsa \
|
|
// RUN: -target-cpu gfx906 -fcuda-is-device -x hip \
|
|
// RUN: -fno-hip-fp32-correctly-rounded-divide-sqrt \
|
|
// RUN: | FileCheck --check-prefixes=COMMON,NCRDIV %s
|
|
|
|
#include "Inputs/cuda.h"
|
|
|
|
typedef __attribute__(( ext_vector_type(4) )) float floatvec4;
|
|
|
|
// COMMON-LABEL: @_Z11spscalardiv
|
|
// COMMON: fdiv{{.*}},
|
|
// NCRDIV: !fpmath ![[MD:[0-9]+]]
|
|
// CRDIV-NOT: !fpmath
|
|
__device__ float spscalardiv(float a, float b) {
|
|
return a / b;
|
|
}
|
|
|
|
// COMMON-LABEL: @_Z11spvectordiv
|
|
// COMMON: fdiv{{.*}},
|
|
// NCRDIV: !fpmath ![[MD]]
|
|
// CRDIV-NOT: !fpmath
|
|
__device__ floatvec4 spvectordiv(floatvec4 a, floatvec4 b) {
|
|
return a / b;
|
|
}
|
|
|
|
// COMMON-LABEL: @_Z11dpscalardiv
|
|
// COMMON-NOT: !fpmath
|
|
__device__ double dpscalardiv(double a, double b) {
|
|
return a / b;
|
|
}
|
|
|
|
// COMMON-LABEL: @_Z12spscalarsqrt
|
|
// NCRDIV: call contract float @llvm.sqrt.f32(float %{{.+}}), !fpmath ![[MD:[0-9]+]]
|
|
// CRDIV: call contract float @llvm.sqrt.f32(float %{{.+}}){{$}}
|
|
__device__ float spscalarsqrt(float a) {
|
|
return __builtin_sqrtf(a);
|
|
}
|
|
|
|
// COMMON-LABEL: @_Z12dpscalarsqrt
|
|
// COMMON: call contract double @llvm.sqrt.f64(double %{{.+}}){{$}}
|
|
// COMMON-NOT: !fpmath
|
|
__device__ double dpscalarsqrt(double a) {
|
|
return __builtin_sqrt(a);
|
|
}
|
|
|
|
// COMMON-LABEL: @_Z28test_builtin_elementwise_f32f
|
|
// NCRDIV: call contract float @llvm.sqrt.f32(float %{{.+}}), !fpmath ![[MD:[0-9]+]]
|
|
// CRDIV: call contract float @llvm.sqrt.f32(float %{{.+}}){{$}}
|
|
__device__ float test_builtin_elementwise_f32(float a) {
|
|
return __builtin_elementwise_sqrt(a);
|
|
}
|
|
|
|
// COMMON-LABEL: @_Z28test_builtin_elementwise_f64d
|
|
// COMMON: call contract double @llvm.sqrt.f64(double %{{.+}}){{$}}
|
|
// COMMON-NOT: !fpmath
|
|
__device__ double test_builtin_elementwise_f64(double a) {
|
|
return __builtin_elementwise_sqrt(a);
|
|
}
|
|
|
|
// NCRSQRT: ![[MD]] = !{float 2.500000e+00}
|